/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.push.imapidle.locking;

import javax.annotation.concurrent.Immutable;

/**
 * {@link SessionInfo} - The session info for the IMAP-IDLE listener.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.6.2
 */
@Immutable
public class SessionInfo {

    private final int contextId;
    private final int userId;
    private final String sessionId;
    private final boolean permanent;
    private final boolean tranzient;

    /**
     * Initializes a new {@link SessionInfo}.
     *
     * @param sessionId The identifier of the associated session
     * @param userId = The user identifier
     * @param contextId = The context identifier
     * @param permanent Whether permanent or not
     * @param tranzient <code>true</code> if session is not supposed to be held in session storage; otherwise <code>false</code>
     */
    public SessionInfo(String sessionId, int userId, int contextId, boolean permanent, boolean tranzient) {
        super();
        this.contextId = contextId;
        this.userId = userId;
        this.sessionId = sessionId;
        this.permanent = permanent;
        this.tranzient = tranzient;
    }

    /**
     * Gets the context identifier.
     *
     * @return The context identifier
     */
    public int getContextId() {
        return contextId;
    }

    /**
     * Gets the user identifier.
     *
     * @return The user identifier
     */
    public int getUserId() {
        return userId;
    }

    /**
     * Gets the session identifier.
     *
     * @return The session identifier
     */
    public String getSessionId() {
        return sessionId;
    }

    /**
     * Gets the permanent flag.
     *
     * @return The permanent flag
     */
    public boolean isPermanent() {
        return permanent;
    }

    /**
     * Signals if associated session is not supposed to be held in session storage.
     *
     * @return <code>true</code> if not held in session storage; otherwise <code>false</code>
     */
    public boolean isTransient() {
        return tranzient;
    }

}
